<?php

namespace App\Data;

use \InvalidArgumentException;

class Color {
    /**
     * @var string 6 bytes unsigned int that represents an RGB color
     */
    private string $hex;

    /**
     * @param string $value 6 bytes unsigned int that represents an RGB color
     * @throws \InvalidArgumentException if the value is negative or greater than 0xFFFFFF
     */
    private function __construct(string $value) {
        $this->value = $value;
    }

    /**
     * @return string
     */
    public function getValue(): string {
        return $this->value;
    }

    public static function from(string $value): Color {
        $color = self::tryFrom($value);
        if ($color == null) {
            throw new InvalidArgumentException("The string is not an hexadecimal code");
        }
        return $color;
    }

    public static function tryFrom(string $value): ?Color {
        if (!preg_match('/#(?:[0-9a-fA-F]{6})/',$value)) {
            return null;
        }
        return new Color($value);
    }

}