<?php

namespace App\Data;


use http\Exception\InvalidArgumentException;

/**
 * Enumeration class workaround
 * As there is no enumerations in php 7.4, this class
 * encapsulates an integer value and use it as an enumeration discriminant
 */
final class MemberRole {

    public const ROLE_PLAYER = 0;
    public const ROLE_COACH = 1;
    private const MIN = self::ROLE_PLAYER;
    private const MAX = self::ROLE_COACH;

    private int $value;

    private function __construct(int $val) {
        if (!$this->isValid($val)) {
            throw new InvalidArgumentException("Valeur du rôle invalide");
        }
        $this->value = $val;
    }

    public static function player(){
        return new MemberRole(MemberRole::ROLE_PLAYER);
    }

    public static function coach(){
        return new MemberRole(MemberRole::ROLE_COACH);
    }

    private function isValid(int $val): bool {
        return ($val <= self::MAX and $val >= self::MIN);
    }

    public function isPlayer(): bool {
        return ($this->value == self::ROLE_PLAYER);
    }

    public function isCoach(): bool {
        return ($this->value == self::ROLE_COACH);
    }

}