<?php

namespace App\Data;

class Team {
    private int $id;
    private string $name;
    private string $picture;
    private Color $mainColor;
    private Color $secondColor;

    /**
     * @var array maps users with their role
     */
    private array $members;

    /**
     * @param string $name
     * @param string $picture
     * @param Color $mainColor
     * @param Color $secondColor
     * @param array $members
     */
    public function __construct(int $id,string $name, string $picture, Color $mainColor, Color $secondColor, array $members =[]) {
        $this->id = $id;
        $this->name = $name;
        $this->picture = $picture;
        $this->mainColor = $mainColor;
        $this->secondColor = $secondColor;
        $this->members = $members;
    }

    /**
     * @return int
     */
    public function getId(): int {
        return $this->id;
    }

    /**
     * @return string
     */
    public function getName(): string {
        return $this->name;
    }

    /**
     * @return string
     */
    public function getPicture(): string {
        return $this->picture;
    }

    /**
     * @return Color
     */
    public function getMainColor(): Color {
        return $this->mainColor;
    }

    /**
     * @return Color
     */
    public function getSecondColor(): Color {
        return $this->secondColor;
    }

    public function listMembers(): array {
        return array_map(fn ($id, $role) => new Member($id, $role), $this->members);
    }

}